==> haskell-concise-0.1.0.1-627-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-8XVa4eH5PJdBg4iUmn35Zt
key:                  concise-0.1.0.1-8XVa4eH5PJdBg4iUmn35Zt
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  82afa3de0c5c85e73ebeae75651e24f1
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-8XVa4eH5PJdBg4iUmn35Zt
depends:
    base-4.17.2.1 bytestring-0.11.5.3 lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-650-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-Fpv1ZCKwo03EvA8ZcwUe9q
key:                  concise-0.1.0.1-Fpv1ZCKwo03EvA8ZcwUe9q
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  766691651c4152c24dbdd4d131d04d48
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-Fpv1ZCKwo03EvA8ZcwUe9q
depends:
    base-4.17.2.1 bytestring-0.11.5.3 lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
